{-
 *  Programmer:	Piotr Borek
 *  E-mail:     piotrborek@op.pl
 *  Copyright 2016 Piotr Borek
 *
 *  Distributed under the terms of the GPL (GNU Public License)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}

module Main where

import           Control.Monad
import qualified Data.Map.Strict                as Map
import           System.Environment

import           Mp.Configuration.AppColors
import           Mp.Configuration.Configuration
import           Mp.Player.Client
import           Mp.Player.Daemon
import           Mp.UI.Main
import           Mp.UI.MpData

import           Simple.UI.Core.Attribute
import           Simple.UI.Core.UIApp

main :: IO ()
main = do
    makeDefaultConfiguration

    conf <- readConfiguration
    songList <- attributeNew []
    songMap <- attributeNew Map.empty
    let appColors = parseColors conf
    let musicDirectory = getMusicDirectory conf
    let mpData = MpData
            { _mpColors = appColors
            , _mpMusicDirectory = musicDirectory
            , _mpSongList = songList
            , _mpSongMap = songMap
            }

    args <- getArgs
    case args of
        [] -> do
            runPlayerDaemon
            runUIApp mpData mainLoop
            printDaemonLog

        ["--daemon"] -> do
            runPlayerDaemon
            printDaemonLog

        -- all below is for testing
        ["--status"] -> do
            (stat, dur, pos) <- clientSendGetStatus
            putStrLn $ "Status:   " ++ stat
            putStrLn $ "Duration: " ++ show dur
            putStrLn $ "Position: " ++ show pos

        ["--quit"] ->
            clientSendQuitMessage

        ["--list"] -> do
            list <- clientSendGetPlaylist
            forM_ list putStrLn

        _  ->
            putStrLn "Wrong number of parameters."
