{-
 *  Programmer:	Piotr Borek
 *  E-mail:     piotrborek@op.pl
 *  Copyright 2016 Piotr Borek
 *
 *  Distributed under the terms of the GPL (GNU Public License)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}

module Mp.UI.Main (
    mainLoop
) where

import           Control.Monad
import qualified Graphics.Vty        as Vty
import           Simple.UI.All

import           Mp.Player.Client
import           Mp.UI.BrowserPage
import           Mp.UI.EditBar
import           Mp.UI.HelpPage
import           Mp.UI.MainMenuBar
import           Mp.UI.MainStatusBar
import           Mp.UI.MpData
import           Mp.UI.PlaylistPage
import           Mp.UI.QueuePage

mainLoop :: UIApp MpData ()
mainLoop = do
    windowLayout <- fillLayoutVerticalNew
    window <- windowNew WindowTypeTopLevel windowLayout

    containerLayout <- singleLayoutNew
    container <- containerNew containerLayout

    menuBar <- mainMenuBarNew containerLayout 1
    addTo window menuBar def { fillLayoutVExpand = False }

    helpPage <- helpPageNew
    addTo container helpPage def

    queuePage <- queuePageNew
    addTo container queuePage def

    playlistPage <- playlistPageNew
    addTo container playlistPage def

    browserPage <- browserPageNew
    addTo container browserPage def

    addTo window container def

    statusBar <- mainStatusBarNew
    addTo window statusBar def { fillLayoutVExpand = False }

    editBar <- editBarNew
    addTo window editBar def { fillLayoutVExpand = False }
    set editBar visible False

    on_ window keyPressed $ \key _ ->
        case key of
            Vty.KChar 'q' -> do
                clientSendSaveState
                mainLoopQuit

            Vty.KChar 'Q' -> do
                clientSendSaveState
                clientSendQuitMessage
                mainLoopQuit

            Vty.KChar 'S' -> do
                i <- get containerLayout layoutIndex
                when (i == 1) $ do
                    set editBar visible True
                    runDialogLoop editBar
                    set editBar visible False
                    playlistPageUpdate playlistPage

            _  ->
                return ()

    runMainLoop window
