{-
 *  Programmer:	Piotr Borek
 *  E-mail:     piotrborek@op.pl
 *  Copyright 2016 Piotr Borek
 *
 *  Distributed under the terms of the GPL (GNU Public License)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}
{-# LANGUAGE QuasiQuotes     #-}
{-# LANGUAGE TemplateHaskell #-}

module Mp.UI.QuestionBar (
    YesNo (..),
    questionBarNew,
    castToQuestionBar,
    answer
) where

import           Control.Lens              (makeLensesFor, (.=))
import qualified Graphics.Vty              as Vty
import           Simple.Locale.TranslateTH
import           Simple.UI.All

import           Mp.Locale.TranslateFile   ()
import           Mp.UI.MpData

data YesNo = Yes
           | No
           deriving Eq

data QuestionBar = QuestionBar
    { _questionBarParent :: Label
    , _questionBarAnswer :: Attribute YesNo
    }

makeLensesFor [("_questionBarParent", "questionBarParent")] ''QuestionBar

class QuestionBarClass w where
    castToQuestionBar :: w -> QuestionBar

    answer :: w -> Attribute YesNo
    answer = _questionBarAnswer . castToQuestionBar

instance QuestionBarClass QuestionBar where
    castToQuestionBar = id

instance TextClass QuestionBar where
    castToText = castToText . _questionBarParent

instance WidgetClass QuestionBar where
    castToWidget = castToWidget . _questionBarParent

    overrideWidget = overrideWidgetHelper questionBarParent

questionBarNew :: UIApp MpData QuestionBar
questionBarNew = do
    mpData <- view appUserData

    label <- labelNew $ Just ([tr|File exists. Overwrite ?|] ++ " (y/n)")

    noAnswer <- attributeNew No
    let questionBar = overrideWidget
                    QuestionBar { _questionBarParent = label
                                , _questionBarAnswer = noAnswer
                                }
                    $ virtualWidgetName .= "questionbar"

    on_ questionBar keyPressed $ \key _ ->
        case key of
            Vty.KChar 'y' -> do
                set questionBar answer Yes
                mainLoopQuit

            Vty.KChar 'Y' -> do
                set questionBar answer Yes
                mainLoopQuit

            Vty.KChar 'n' -> do
                set questionBar answer No
                mainLoopQuit

            Vty.KChar 'N' -> do
                set questionBar answer No
                mainLoopQuit

            _             -> return ()

    set questionBar colorForeground $ mpData ^. mpColors . editForeground
    set questionBar colorBackground $ mpData ^. mpColors . editBackground

    return questionBar
