{-
 *  Programmer:	Piotr Borek
 *  E-mail:     piotrborek@op.pl
 *  Copyright 2014 Piotr Borek
 *
 *  Distributed under the terms of the GPL (GNU Public License)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-}

module Mp.Utils.Utils where

import           Control.Monad
import           Control.Monad.Catch
import           Graphics.Vty

toVtyColor :: String -> Color
toVtyColor color = case color of
    "black"         -> black
    "white"         -> white
    "cyan"          -> cyan
    "magenta"       -> magenta
    "blue"          -> blue
    "yellow"        -> yellow
    "green"         -> green
    "red"           -> red
    "brightBlack"   -> brightBlack
    "brightYellow"  -> brightYellow
    "brightGreen"   -> brightGreen
    "brightRed"     -> brightRed
    "brightBlue"    -> brightBlue
    "brightWhite"   -> brightWhite
    "brightMagenta" -> brightMagenta
    "brightCyan"    -> brightCyan
    _               -> black

whenM :: Monad m => m Bool -> m () -> m ()
whenM cond action = do
    b <- cond
    when b action

timeToString :: Integer -> String
timeToString time =
    let h  = time `div` 3600
        m  = show $ (time `div` 60) `mod` 60
        m' = if length m < 2 then "0" ++ m
             else m
        s  = show $ time `mod` 60
        s' = if length s < 2 then "0" ++ s
             else s
    in
        if h == 0 then m ++ ":" ++ s'
        else show h ++ ":" ++ m' ++ ":" ++ s'

separateFilePath :: String -> (String, String)
separateFilePath file =
    let (f, d) = span (/= '/') $ reverse file
    in (reverse $ tail d, reverse f)

catchIgnoreAll :: MonadCatch m => m () -> m ()
catchIgnoreAll action = catchAll action (const $ return ())
